@@ -63,20 +63,24 @@ def all_requests(func):
     return inner
 
 
-def urlmatch(scheme=None, netloc=None, path=None):
+def urlmatch(scheme=None, netloc=None, path=None, method=None):
     def decorator(func):
         @wraps(func)
         def inner(self_or_url, url_or_request, *args, **kwargs):
             if isinstance(self_or_url, urlparse.SplitResult):
                 url = self_or_url
+                request = url_or_request
             else:
                 url = url_or_request
+                request = args[0]
             if scheme is not None and scheme != url.scheme:
                 return
             if netloc is not None and not re.match(netloc, url.netloc):
                 return
             if path is not None and not re.match(path, url.path):
                 return
+            if method is not None and method.upper() != request.method:
+                return
             return func(self_or_url, url_or_request, *args, **kwargs)
         return inner
     return decorator
